function motor = Optimering_test(torque, diameter, length, vll, minpf, efficiency, Const)

tic

                              %% Variables from tool %%

% 1 motor.variables.C_DO            % Outer conductor diamter (active material) [m]
% 2 motor.variables.C_d             % Conductor depth
% 3 motor.variables.Np              % Number of poles
% 4 motor.variables.J               % [A/mm^2] Current density / del av el ??
% 5 motor.variables.N_lay           % Number of coil layers
% 6 motor.variables.alpha_m         % Ratio between magnet width/pitch and pole pitch
% 7 motor.geom.g                    % Air gap length [m]
% 8 motor.geom.M_d                  % Magnet depth. M finne anna mte  regne ut denne p. Variabel?





                        %% Boundaries and start points %%

UB_1 = 1.00;         
LB_1 = 0.2;                     % Outer diamter (active material) [m]
x1_0 = 0.40;  
UB_2 = 4e-3*10;                
LB_2 = 1e-3*10;               % Conductor depth [m]
x2_0 = 1.7e-3*10;
UB_3 = 60e-3;         
LB_3 = 20e-3;                    % Number of poles
x3_0 = 39e-3;
UB_4 = 8;       
LB_4 = 3;                     % [A/mm^2] Current density
x4_0 = 5.5;
UB_5 = 34e-3;         
LB_5 = 12e-3;                     % Number of coil layers.
x5_0 = 18e-3;
UB_6 = 0.99;        
LB_6 = 0.2;                   % Ratio between magnet width/pitch and pole pitch
x6_0 = 0.6;
UB_7 = 6e-3*10;         
LB_7 = 1e-3*10;                % Air gap length [m]
x7_0 = 2e-3*10;
UB_8 = 10e-3*10;          
LB_8 = 5e-3*10;                   % Magnet depth.
x8_0 = 6.667e-3*10;

global globalT
global globalD
global globalL
global globalVLL
global globalPF
global globalEFF
global globalC


globalT = torque;
globalD = diameter;
globalL = length;
globalVLL = vll;
globalPF = minpf;
globalEFF = efficiency;
globalC = Const;

LB = [LB_1 LB_2 LB_3 LB_4 LB_5 LB_6 LB_7 LB_8];
UB = [UB_1 UB_2 UB_3 UB_4 UB_5 UB_6 UB_7 UB_8];
x_0 = [x1_0 x2_0 x3_0 x4_0 x5_0 x6_0 x7_0 x8_0];

%% Performing the optimisation using the built-in function ga in matlab %%

clear fval X exitflag output
% 'UseParallel', 'always',
%,'HybridFcn', {@fmincon,hybridopts} nr man kjrer hybrid
hybridopts = optimset('Algorithm','interior-point' ,'MaxFunEvals',1500,'TolCon',1e-10,'TolX',1e-12,'ObjectiveLimit',0)

options = gaoptimset('FitnessScalingFcn', {@fitscalingrank }, 'popInitRange', [LB ; UB],'stallGenL', 10, 'Generations', 20, 'PopulationSize', 25, 'EliteCount', 2, 'CrossoverFraction', 0.4, 'MigrationFraction', 10, 'MigrationFraction', 0.1, 'MigrationDirection', 'both', 'PopulationType', 'doubleVector', 'SelectionFcn', { @selectiontournament [] },'HybridFcn', {@fmincon,hybridopts}); 

% intcons = [3, 5]; % Np and Nlay are integers
%setup for use of the function ga for integer variables
[X fval exitflag output population scores] = ga (@AnalyticTool_fun_test, 8, [], [], [], [], LB, UB, @AnalyticTool_con_test, options); 

% optionsGBO = optimset('Algorithm', 'interior-point', 'MaxFunEvals', 1500, 'TolCon', 1e-10, 'TolX', 1e-12, 'ObjectiveLimit', 0);

% [X2 fval exitflag output] = fmincon( @AnalyticTool_fun_test, x_0, [], [], [], [], LB, UB, @AnalyticTool_con_test, hybridopts);

% [f c ceq motor]=AnalyticTool(X)
[f c ceq motor]=AnalyticTool_test(X);

disp(' ')
disp('Optimal machine geometry');
disp(' ');
disp(['Weight of materials:         ',num2str(round(motor.mech.M_weight)),'[kg]']);
% disp(['Total cost:                  ',num2str(round(motor.cost.total)),'[Euro ]']);
disp(['Cost of active materials:    ',num2str(round(motor.cost.mech)),'[Euro ]']);
% disp(['Cost of energy loss:         ',num2str(round(motor.cost.E_total)),'[Euro ]']);
disp(['Outer diameter:              ',num2str(round(motor.variables.C_DO*1000)),' [mm]']);
disp(['Active length:               ',num2str(round(motor.mech.M_totL*1000)),' [mm]']);
disp(['Conductor depth (axial):     ',num2str(motor.variables.C_d*1000), '[mm]']);
disp(['Cond actiev length(radial):  ',num2str(motor.geom.C_l*1000), '[mm]']);
disp(['Conductor width:             ',num2str(motor.geom.C_w_avg*1000), '[mm]']);
disp(['Copper current density:      ',num2str(round(motor.variables.J*1000)/1000),' [A/mm^2]']);
disp(['DC loss:                     ',num2str(round(motor.el.P_DC)),'[W]']);
disp(['Efficiency:                  ',num2str(round(motor.el.efficiency*1000)/10),'[%]']);
disp(['Yearly energy loss:          ',num2str(round(motor.el.E_loss_yearly)),'[kWh]']);
disp(['Yearly cost of energy loss:  ',num2str(round(motor.cost.E_loss_yearly)),'[Euro ]']);
disp(['Total lifetime energy cost:  ',num2str(round(motor.cost.E_total)),'[Euro ]']);
disp(['Power factor:                ',num2str(round(motor.el.cos_phi*100)/100)]);
disp(['Line voltage, rms:           ',num2str(round(motor.el.V_ll_rms)),'[V]']);
disp(['Number of turns:             ',num2str(motor.variables.N_lay)]);
disp(['Number of poles:             ',num2str(motor.variables.Np)]);
disp(['Number of slots:             ',num2str(motor.geom.Ns)]);
disp(['Slot depth (Axial):          ',num2str(round(motor.geom.L_alength*1000)),'[mm]']);
disp(['Slot width:                  ',num2str(motor.geom.w_s*1000),'[mm]']);
disp(['Tooth width:                 ',num2str(motor.geom.w_lam*1000),'[mm]']);
disp(['Air gap length:              ',num2str(motor.variables.g*1000),'[mm]']);
disp(['Magnet length(axial):        ',num2str(motor.variables.M_d*1000),'[mm]']);
disp(['Magnet length(radial):        ',num2str(motor.geom.M_l*1000),'[mm]']);
disp(['Magnet width:                ',num2str(motor.geom.M_w*1000),'[mm]']);
disp(['Alpha_magnet:                ',num2str(motor.variables.alpha_m)]);
disp(['Pole pitch:                  ',num2str(motor.geom.tau_p),]);
disp(['Back Iron thickness:         ',num2str(round(motor.geom.BI_D*1000)),'[mm]']);
disp(['Number of machines:          ',num2str(round(motor.geom.M))]);
disp(['Aluminum weight:             ',num2str(round(motor.mech.M_conductor)),'[kg]']);
disp(['Magnet weight:               ',num2str(round(motor.mech.M_pm)),'[kg]']);
disp(['Iron weight:                 ',num2str(round(motor.mech.M_laminations)),'[kg]']);
disp(['Steel weight:                ',num2str(round(motor.mech.M_BI+motor.mech.M_shaft+motor.mech.M_housing)),'[kg]']);
disp(['Aluminum cost:               ',num2str(round(motor.cost.conductors)),'[Euro ]']);
disp(['Magnet cost:                 ',num2str(round(motor.cost.PM)),'[Euro ]']);
disp(['Iron cost:                   ',num2str(round(motor.cost.laminations)),'[Euro ]']);
disp(['Steel cost:                  ',num2str(round(motor.cost.BI+motor.cost.Shaft+motor.cost.Housing)),'[Euro ]']);
disp(['Torque:                      ',num2str((motor.mech.T )),'[Nm]']);
disp(['Eph:                         ',num2str((motor.el.E_ph_rms )),'[V]']);
disp(['I:                           ',num2str(motor.el.Iph_rms)]);
disp(' ')
% disp('Additional');
% disp(' ');
% disp(['Conductor width:             ',num2str(motor.geom.C_w_avg)]);
% disp(['X:                           ',num2str(motor.el.omega_e*motor.el.L_ph)]);
% disp(['L_Ph:                        ',num2str(motor.el.L_ph)]);   
% disp(['Vll:                         ',num2str(motor.el.V_ll_rms)]);
% disp(['V_X_ph:                      ',num2str(motor.el.V_X_ph_rms)]);
% disp(['Eph:                         ',num2str(motor.el.E_ph_rms)]);
% disp(['Fill factor:                 ',num2str(motor.geom.k_winding)]);
% disp(['R_iron:                      ',num2str(motor.geom.R_iron)]);
% disp(['k_D:                         ',num2str(motor.geom.k_D)]);
toc                               