function [f c ceq motor]=AnalyticTool(varb)
%varb

clc
clear motor

motor = struct('error',0);              %Declaring ms as a struct

                     %% Variable parameters %%

motor.variables.C_DO = varb(1);                   % Outer conductor diamter (active material) [m] 
motor.variables.C_d = varb(2)/10;                 % Conductor depth [m]
motor.variables.Np = varb(3)*1000;                % Number of poles
motor.variables.J = varb(4);                      % [A/mm^2] Current density / del av el ??
motor.variables.N_lay = varb(5)*1000;             % Number of coil layers
motor.variables.alpha_m = varb(6);                % Ratio between magnet width/pitch and pole pitch
motor.variables.g = varb(7)/10;                   % Air gap length [m]
motor.variables.M_d = varb(8)/10;                 % Magnet depth. [m]
%motor.variables.k_D = varb(9);                    % Ratio between outer and inner diameter
%motor.variables.q = varb(9);                    % Number of slots per phase per pole

motor.variables.Np= round(motor.variables.Np);
motor.variables.N_lay = round(motor.variables.N_lay);

% motor.variables.C_DO = 360/1000;                % Outer conductor diamter (active material) [m] 
% motor.variables.Np = 40;                        % Number of poles
% motor.variables.J = 10.3;                       % [A/mm^2] Current density / del av el ??
% motor.variables.alpha_m = 0.8;                  % Ratio between magnet width/pitch and pole pitch
% motor.variables.g = 1/1000;                     % Air gap length [m]
% motor.variables.M_d = (20/3)/1000;              % Magnet depth. M finne anna mte  regne ut denne p. Variabel?
% motor.variables.N_lay = 21;                     % Number of coil layers
% motor.variables.C_d = 1.5/1000;                 % Conductor depth (1.5 mm)


                             %% Constants %%
            
motor.constant.my_0 = 4*pi*1e-7;        % Relative permeability of vacuume
motor.constant.my_iron = 5000;          % Relative permeability of iron
motor.constant.my_pm = 1.05;            % Relative permeability of permanent magnet
motor.constant.my_air = 1;              % Relative permeability of air
motor.constant.sigma_alu = 35e6;        % [S/m]Conductivity of aluminium at 20 degrees (26.06.2014 http://en.wikipedia.org/wiki/Electrical_resistivity_and_conductivity) 
motor.constant.sigma_steel = 10.4e6;    % [S/m]Conductivity of steel
motor.constant.sigma_air = 0;           % [S/m]Conductivity of air
motor.constant.rho_alu = 2700;          % Density of aluminium (26.06.2014 http://en.wikipedia.org/wiki/Aluminium) [kg/m^3]
motor.constant.rho_pm = 7700;           % Density of permanent magnet[kg/m^3]
motor.constant.rho_steel = 7870;        % Density of steel [km/m^3]
motor.constant.rho_lamination = 7870;   % Density of stator steel [kg/m^3]
motor.constant.lifetime = 20;           % Estimated lifetime of a motor


                                    %% Costs %% (ref needed for everything)
            
 motor.cost.C_laminations = 4;          % Euro pr. kilo material. Based on (Ref needed. Astrid)
 motor.cost.C_pm = 85;                  % Euro pr. kilo material. (ref needed)
 motor.cost.C_aluconductor = 1274.78/1000;         % Euro pr. kilo material. (26.06.2014: http://www.indexmundi.com/commodities/?commodity=aluminum&months=120&currency=eur)
 motor.cost.C_steel = 6;                % Euro pr. kilo material. (ref needed)
 motor.cost.disc_rate = 0.2;            % Discount rate.
 motor.cost.E_price = 0.24;             % Energy price [Euro/kWh].

   
                                %% Set Parameters %%

motor.el.Eph_req = 125;                 % Min back emf [V]
motor.el.V_t_Req = 320;                 % Required line to line voltage  [V]                          
motor.mech.n = 30;                      % Mechanical rotational speed [rpm]
motor.mech.T_req = 6250;                % Required mechanical power [Nm] P_req
motor.mag.Br = 1.3;                     % Magnetic remenance flux density [T]
motor.el.N_ph = 3;                      % Number of phases 
motor.geom.q = 1;                       % Slots pr. phase pr. pole
motor.geom.C_layg = 0.5/1000;           % Gap between cunductor layers. = d_wedge?
motor.geom.L_ed = 1/1000;               % [m] Lamination ekstra depth (
motor.geom.k_D= 0.6;                    % Ratio between out and inner diameter
motor.mech.Shaft_d = 20e-3;             % Shaft thickness [m]
motor.mech.time_fullP = 10;             % Hours yearly with full power consumption



                                %% Limitations %%
                                
lim_f = 30;                     % Maximum allowable frequency [Hz]
lim_tooth = 3e-3;               % Minimum allowable tooth width [m]
Lim_PF = 0.75;                  % Minimum power factor.
Lim_Riron = 0.9;                % Max ratio between iron and air gap surface area
     

                                     %% Dependent parameters %%
                                     
motor.geom.c_totd = motor.variables.N_lay*(motor.variables.C_d+motor.geom.C_layg)-motor.geom.C_layg; % Stator active axial depth
motor.geom.L_alength = motor.geom.c_totd+(2*motor.geom.L_ed);                                              % lamination axial length [m]                                     
motor.geom.Ns = motor.geom.q*motor.el.N_ph*motor.variables.Np;              % Number of slots
motor.el.f = motor.variables.Np*motor.mech.n/(60*2);                        % Electrical frequency
motor.mech.omega_m = motor.mech.n*2*pi/60;                                  % Mechanical speed [rad/s]
motor.el.omega_e = 2*pi*motor.el.f;                                         % Electrical speed [rad/s]

motor.geom.tau_p = 2*pi/motor.variables.Np;                                 % Pole pitch [rad]
motor.geom.tau_s = 2*pi/motor.geom.Ns;                                      % Slot pitch [rad] eller Ts = Tp/(ph*q)
motor.geom.tau_m = motor.geom.tau_p*motor.variables.alpha_m;                % Magnet pitch (am -> ratio between magnet pitch and pole pitch)

motor.geom.C_DI = motor.variables.C_DO*motor.geom.k_D;                      % Inner diameter of active coil
motor.geom.C_l = (motor.variables.C_DO-motor.geom.C_DI)/2;                  % Conductor length (straigth area) =/ magnet length or slot radial length

motor.geom.r_O = motor.variables.C_DO/2;                                    % Outer radius of active material (med house diamter?)
motor.geom.r_I = motor.geom.C_DI/2;                                         % Inner radius of active material ndvendig?
motor.geom.r_avg = (motor.variables.C_DO+motor.geom.C_DI)/4;                % Average radius

motor.geom.L_lam = motor.geom.C_l;                                                      % slot depth (Radial length)
motor.geom.M_DO = motor.variables.C_DO*1.01;                                            % Magnet outer diameter
motor.geom.M_DI = motor.geom.C_DI*0.99;                                                 % Magnet inner diameter
motor.geom.M_l = (motor.geom.M_DO-motor.geom.M_DI)/2;                                   % Magnet length
motor.geom.M_w = motor.geom.tau_m*motor.geom.r_avg;                                     % Average magnet width
motor.geom.R_iron = (motor.geom.tau_s*motor.geom.C_l)/(motor.geom.tau_m*motor.geom.M_l);% Ration between iron and air gap surface area 
motor.geom.w_lam = 2*motor.geom.r_avg*tan(motor.geom.tau_s/2)*(motor.geom.R_iron);      % Slot width
motor.geom.BI_D = motor.variables.M_d;                                                  % Back Iron axial depth
motor.geom.C_g = motor.geom.w_lam;                                                      % Gap between conductors.
motor.geom.k_winding = 1 -((motor.geom.C_g*motor.geom.C_l*motor.geom.q*motor.el.N_ph*motor.variables.Np)/(pi*((motor.variables.C_DO/2)^2-(motor.geom.C_DI/2)^2)));  % Fill factor (slotless), C_g = mellomrom mellom ledere, C_l = lenge av rett omrde p leder, q*ph*p=N_s
motor.geom.w_s = (motor.geom.tau_s*motor.geom.r_avg)-motor.geom.w_lam;                  % gap between slots

motor.geom.C_w_avg = 2*motor.geom.r_avg*tan(motor.geom.tau_s/2)*(1-motor.geom.R_iron);  % Average conductor width. (straight area)                                  
motor.el.alpha_slot = 2*pi*motor.variables.Np/2/motor.geom.Ns;                 % Slot angle [rad]

                                %%coefficients %%

motor.geom.k_c = (1-(2*motor.geom.w_s/(pi*motor.geom.tau_s))*(atan(motor.geom.w_s/motor.variables.g))-(motor.variables.g/(2*motor.geom.w_s))*log(1+(motor.geom.w_s/motor.variables.g)^2))^-1;
% Carters coefficient from (ref hanselmannn)
motor.geom.tau_c = motor.geom.tau_p;
motor.geom.k_p = motor.geom.tau_c/motor.geom.tau_p;                 %Pitchin factor, k_p = tau_c/tau_p, tau_c = tau_p, theta_ce = pi osv osv
motor.geom.theta_se = pi/(motor.geom.q*motor.el.N_ph);              % Slot pitch
motor.geom.k_d = sin(motor.geom.q*motor.geom.theta_se/2)/(motor.geom.q*sin(motor.geom.theta_se/2)); % Distribution factor = 1
motor.geom.k_w = motor.geom.k_p*motor.geom.k_d;                     % Winding factor = 1 because of q = 1;



                                %% Reluctances and permeances per meter radial length %%
                               
motor.mag.R_pm = motor.variables.M_d/(motor.constant.my_0*motor.geom.M_w); % Permanent magnet reluctance. Only half of the width.
motor.mag.R_g = motor.variables.g*motor.geom.k_c/(motor.constant.my_0*motor.geom.M_w);       % Air gap reluctance. Half magnet width.
motor.mag.R_s = motor.geom.L_alength/(motor.constant.my_0*motor.constant.my_iron*motor.geom.w_lam); % Slot permeance, w_lam = Lamination with width and L_alength = Lamination length axially
motor.mag.R_ml = ((motor.constant.my_0/pi)*log(1+pi*motor.variables.g/(motor.geom.tau_p-motor.geom.tau_m)))^-1;
motor.mag.R_ml = real(motor.mag.R_ml);                                                  % Because R_ml might become imaginary
motor.mag.R_mr = (motor.constant.my_0/pi*log(1+(pi*min(motor.variables.g,(motor.geom.tau_p-motor.geom.M_w)/2)/motor.variables.M_d)))^-1;                % leakage from magnet to rotor
motor.mag.R_l = motor.geom.w_s/(motor.constant.my_0*(1/2)*motor.geom.L_alength);              % Leakage reluctance between stator teeth
motor.mag.R_m = (2*motor.mag.R_pm)*motor.mag.R_mr/((2*motor.mag.R_pm)+motor.mag.R_mr);          % Parallel reluctance of 2*R_pm and R_mr

motor.mag.R_1 = motor.mag.R_ml*2*motor.mag.R_m/(motor.mag.R_ml+(2*motor.mag.R_m));              % Parallel reluctance of 2*R_m and R_ml
motor.mag.R_2 = ((4*motor.mag.R_g)+motor.mag.R_1)*motor.mag.R_l/((4*motor.mag.R_g)+motor.mag.R_1+motor.mag.R_1); % Parallel reluctance of (4R_g+R_1) and R_l

motor.mag.phi_m = motor.mag.Br*motor.geom.M_w;                                                  % Magnetic flux from magnet

motor.mag.phi_g = (motor.mag.R_1/(motor.mag.R_2+(4*motor.mag.R_g)+motor.mag.R_1))*motor.mag.phi_m;  % Air gap flux
motor.mag.B_g = (motor.mag.R_1/(motor.mag.R_2+(4*motor.mag.R_g)+motor.mag.R_1))*motor.mag.Br;       % Air gap flux density

                                        %% El %%                                       


motor.el.Iph_rms = motor.variables.J*motor.geom.C_w_avg*motor.variables.C_d*(1000^2);

fit = 0;
n_t = motor.variables.N_lay;
M = 0;
while fit==0
    
    M = M+1;
    L_s = (1/2)*(n_t^2)*motor.constant.my_0*motor.geom.L_alength*motor.geom.C_l/(motor.geom.w_s*3);                   % Inductance per slot Hanselmann
    L_g = (n_t^2)*motor.constant.my_0*motor.geom.C_l*motor.geom.tau_p/(4*(motor.variables.M_d+motor.variables.g));       % Airgap inductance per coil Hanselmann. 
    L_es = ((n_t^2)*motor.constant.my_0*motor.geom.tau_p/8)*log((motor.geom.tau_p^2)*pi/(4*motor.geom.L_alength*motor.geom.w_s));   % End section leakage inductance approximation
    L_coil = 2*L_g+L_s+L_es;                                                                % Total inductance per coil. Hanselmann
    motor.el.L_ph = L_coil*motor.variables.Np;                                              % Inductance of all coils in a series (1 phase) N_p, eller N_p/2, eller N_s/2??
    
    R_active = (motor.geom.C_l/(motor.constant.sigma_alu*motor.geom.C_w_avg*motor.variables.C_d))*motor.variables.Np*n_t*motor.geom.q;                                        % Resistance of active coil (Pr phase)
    R_es_upper = (6*motor.geom.tau_s*(motor.variables.C_DO/2)/(motor.constant.sigma_alu*motor.geom.C_w_avg*(motor.variables.C_d/2)))*(motor.variables.Np/2)*n_t*motor.geom.q; % Resistance of upper end section (Pr phase)
	R_es_lower = (6*motor.geom.tau_s*(motor.geom.C_DI/2)/(motor.constant.sigma_alu*motor.geom.C_w_avg*(motor.variables.C_d/2)))*(motor.variables.Np/2)*n_t*motor.geom.q;      % Resistance of lower end section (Pr phas)
    
    motor.el.E_ph_rms      = (1/sqrt(2))*motor.el.omega_e*motor.geom.q*n_t*motor.geom.q*motor.mag.B_g*motor.geom.tau_p*motor.geom.r_avg*motor.geom.C_l*(motor.variables.Np/2)*M;                     % RMS induced phase voltage
    %motor.el.I_ph_rms      = motor.el.I_s_rms/n_t;                             % RMS phase current
    motor.el.R_loss        = (R_active+R_es_upper+R_es_lower)*M;                      % Resistance equivalent for the total electrical losses.
    motor.el.V_R_ph_rms    = motor.el.Iph_rms*motor.el.R_loss;                  % Active RMS voltage drop
    motor.el.V_X_ph_rms    = motor.el.Iph_rms*motor.el.omega_e*motor.el.L_ph;   % Reactive RMS voltage drop
    motor.el.V_ph_rms  = sqrt((motor.el.E_ph_rms+motor.el.V_R_ph_rms)^2 + motor.el.V_X_ph_rms^2);                                                  % Terminal RMS phase voltage
    motor.el.V_ll_rms      = sqrt(3)*motor.el.V_ph_rms;                          % Terminal RMS line voltage
    motor.el.S_base = sqrt(3)*motor.el.V_ll_rms *motor.el.Iph_rms;

    if M == 0                                                           
        M = 1;
    end
   	if motor.el.E_ph_rms >=motor.el.Eph_req
        fit=1;                                                          % Quit while-loop
    end


end

motor.geom.M = M;
motor.mech.T = motor.geom.M*motor.variables.C_d*motor.variables.Np*motor.mag.B_g*motor.variables.N_lay*motor.geom.q*2*sqrt(2)*motor.variables.J*motor.geom.C_w_avg*cos(pi/6)*motor.geom.C_l*motor.geom.r_avg*1000^2;
motor.el.cos_phi = (motor.el.E_ph_rms+motor.el.V_R_ph_rms)/motor.el.V_ph_rms;


                                %% Calculation of mass %% 
                            
% Stator Lamination

motor.mech.V_laminations = motor.geom.w_lam*motor.geom.L_alength*motor.geom.L_lam*motor.geom.Ns;     % [m^3] stator lamination volume
motor.mech.M_laminations = (motor.mech.V_laminations)*motor.constant.rho_lamination*motor.geom.M; % [kg] Weight of laminations

% Conductors
motor.mech.V_c_active = motor.geom.C_l*motor.geom.C_w_avg*motor.variables.C_d*motor.variables.N_lay*motor.geom.Ns;                              % Volume of active conductors
motor.mech.V_es_upper = 6*motor.geom.tau_s*(motor.variables.C_DO/2)*motor.geom.C_w_avg*(motor.variables.C_d/2)*motor.variables.N_lay*(motor.geom.Ns/2); % Upper end coil volume
motor.mech.V_es_lower = 6*motor.geom.tau_s*(motor.geom.C_DI/2)*motor.geom.C_w_avg*(motor.variables.C_d/2)*motor.variables.N_lay*(motor.geom.Ns/2);    % Inner end coil volume
motor.mech.V_conductor = (motor.mech.V_es_upper + motor.mech.V_es_lower + motor.mech.V_c_active)*motor.geom.M;                     % [m^3] volume of conductors (fill factor osv)

motor.mech.M_conductor = motor.mech.V_conductor*motor.constant.rho_alu;  % [kg] Weight of conductors

% Magnets

motor.mech.V_pm = (motor.variables.M_d*motor.geom.M_l*motor.geom.M_w)*motor.variables.Np*2*motor.geom.M;             % [m^3] Magnet volume (2 Rotor discs)
motor.mech.M_pm = motor.mech.V_pm*motor.constant.rho_pm;                                            % [kg] Weight of PM's

% Rotor  Steel (Back Iron)

motor.mech.V_BI = (2*motor.geom.BI_D*(((motor.geom.M_DO/2)^2)-((motor.geom.M_DI/2)^2))*pi);   % [m^3] Back Iron Volume (2 rotor discs)
motor.mech.M_BI = motor.mech.V_BI*motor.constant.rho_steel;                                 % [kg] Weight of back iron

% Housing and shaft approximations. 

motor.mech.M_totL = motor.geom.M*(motor.geom.L_alength+(2*(motor.variables.g+motor.variables.M_d+motor.geom.BI_D)));        % Total machine length
motor.mech.V_shaft = (((((motor.geom.C_DI/4)+(motor.mech.Shaft_d/2))/2)^2)-((((motor.geom.C_DI/4)-(motor.mech.Shaft_d/2))/2)^2))*pi*motor.mech.M_totL; % Shaft volume
motor.mech.M_shaft = motor.constant.rho_steel*motor.mech.V_shaft;                                       % Shaft weight 

motor.mech.D_housing = motor.variables.C_DO+(10/1000);                                      % Housing inner diameter
motor.mech.V_housing = (motor.mech.M_totL/motor.geom.M)*pi*((((motor.mech.D_housing+(20/1000))/2)^2)-((motor.mech.D_housing/2)^2));
motor.mech.M_housing = motor.constant.rho_steel*motor.mech.V_housing;



                                    %% Cost calculation %% 

motor.cost.laminations = motor.mech.M_laminations*motor.cost.C_laminations;   % [Euro ] Lamination material cost
motor.cost.PM = motor.mech.M_pm*motor.cost.C_pm;                              % [Euro ] Permanent magnet material cost
motor.cost.conductors = motor.mech.M_conductor*motor.cost.C_aluconductor;      % [Euro ] Conductor material cost
motor.cost.BI = motor.mech.M_BI*motor.cost.C_steel;                           % [Euro ] Back iron material cost
motor.cost.Shaft = motor.mech.M_shaft*motor.cost.C_steel;                     % [Euro ] Shaft material cost
motor.cost.Housing = motor.mech.M_housing*motor.cost.C_steel;                 % [Euro ] Housing material cost
                                     
                                        %% Losses %% 

% Conductor resistance pr M

motor.el.R_active = (motor.geom.C_l/(motor.constant.sigma_alu*motor.geom.C_w_avg*motor.variables.C_d))*motor.variables.Np*motor.variables.N_lay*motor.geom.q;                                        % Resistance of active coil (Pr phase)
motor.el.R_es_upper = (6*motor.geom.tau_s*(motor.variables.C_DO/2)/(motor.constant.sigma_alu*motor.geom.C_w_avg*(motor.variables.C_d/2)))*(motor.variables.Np/2)*motor.variables.N_lay*motor.geom.q; % Resistance of upper end section (Pr phase)
motor.el.R_es_lower = (6*motor.geom.tau_s*(motor.geom.C_DI/2)/(motor.constant.sigma_alu*motor.geom.C_w_avg*(motor.variables.C_d/2)))*(motor.variables.Np/2)*motor.variables.N_lay*motor.geom.q;      % Resistance of lower end section (Pr phas)

motor.el.R_DC = motor.geom.M*(motor.el.R_active + motor.el.R_es_upper + motor.el.R_es_lower); % Total DC resistance pr phase. 

% DC losses

motor.el.P_DC = motor.el.R_DC*motor.el.N_ph*(motor.el.Iph_rms^2);

% AC losses

motor.el.delta = sqrt(2/(motor.el.omega_e*motor.constant.my_0*motor.constant.sigma_alu));
motor.el.R_ec = (motor.geom.L_alength*motor.geom.C_l*(motor.variables.C_d^2)*(motor.variables.N_lay^2)/(9*motor.constant.sigma_alu*(motor.el.delta^4)*motor.geom.w_s));
motor.el.P_ec = motor.el.R_ec*motor.el.Iph_rms*motor.geom.Ns*motor.geom.M;

% Efficiency 

motor.el.efficiency = (motor.mech.T*motor.mech.omega_m)/(sqrt(3)*motor.el.V_ll_rms*motor.el.Iph_rms);

                                    %% Objective function %% 

motor.mech.M_weight = (motor.mech.M_laminations + motor.mech.M_conductor + motor.mech.M_pm + motor.mech.M_BI+motor.mech.M_shaft+motor.mech.M_housing); % [kg] total weight of machine
motor.cost.mech = motor.cost.laminations + motor.cost.PM + motor.cost.conductors + motor.cost.BI+motor.cost.Housing+motor.cost.Shaft; % [Euro ] Material cost of machine

motor.el.E_loss_yearly = (motor.el.P_DC+motor.el.P_DC)*(3600/1000)*motor.mech.time_fullP;
motor.cost.E_loss_yearly = motor.el.E_loss_yearly*motor.cost.E_price;
motor.cost.E_total = 0;

for k=1:motor.constant.lifetime
    motor.cost.E_total = motor.cost.E_total + (motor.cost.E_loss_yearly/((1+ motor.cost.disc_rate)^k));
end

motor.cost.total = motor.cost.E_total + motor.cost.mech;

% f = [];
% f = motor.cost.total;
% f = motor.mech.M_weight;
 f = motor.cost.mech;

                                    %% Inequality constraints %%

c = [
    (motor.el.f-lim_f)*0.01;                                   % f <= lim_f
     (-motor.mech.T+motor.mech.T_req)/1000;                    % T >= T_req                    
    -motor.geom.w_lam+lim_tooth;                               % w_lam >= lim_tooth
    -motor.geom.C_w_avg;                                       % C_W >= 0
    -motor.geom.r_I;                                           % R_inner >= 0
     (-motor.el.E_ph_rms+motor.el.Eph_req)*0.001;              % Eph > Eph_req
     real(-motor.el.cos_phi+Lim_PF);                          % Cos(phi)> Lim_pf
     (motor.geom.R_iron-Lim_Riron)                            % R_iron =< 0.9
    ];
                               
                                
                                %% Equality constraints %% 
                                
ceq = [];


